@@ -4,6 +4,12 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 30.12.2015: Added option for 'exact' matching.
+# 30.12.2015: Fixed option 'word' matching not saved.
+# 13.11.2015: Added attribute drop.sex.
+# 13.11.2015: Added option to calculate Hb as LMW / HMW.
+# 08.11.2015: Added automatic calculation of average peak height 'H'.
+# 21.10.2015: Added attributes.
 # 28.08.2015: Added importFrom
 # 17.08.2015: Changed erroneus  to  option 'High peak / low peak' to 'Smaller peak / larger peak'.
 # 08.06.2015: Added option to drop sex markers (Fixes issue#9).
@@ -19,11 +25,6 @@
 # 27.11.2013: Passed debug to calculateBalance.
 # 21.10.2013: Fixed dropdown state not loaded.
 # 09.09.2013: Added option 'hb' to specify the definition of Hb.
-# 26.07.2013: Removed parameters 'minHeight', 'maxHeight', 'matchSource' and related code.
-# 26.07.2013: Changed parameter 'fixed' to 'word' for 'checkSubset' function.
-# 18.07.2013: Check before overwrite object (new function).
-# 17.07.2013: Added check subsetting.
-# 11.07.2013: Added save GUI settings.
 
 #' @title Calculate Balance
 #'
@@ -150,7 +151,7 @@ calculateBalance_gui <- function(env=parent.frame(), savegui=NULL,
       svalue(f4_save_edt) <- paste(val_obj, "_balance", sep="")
       
       # Detect kit.
-      kitIndex <- detectKit(.gData)
+      kitIndex <- detectKit(.gData, index=TRUE)
       # Select in dropdown.
       svalue(f4_kit_drp, index=TRUE) <- kitIndex
       
@@ -222,7 +223,7 @@ calculateBalance_gui <- function(env=parent.frame(), savegui=NULL,
     val_ref <- .gRef
     val_ignore <- svalue(f1_ignore_chk)
     val_word <- svalue(f1_word_chk)
-    
+
     if (!is.null(.gData) || !is.null(.gRef)){
       
       chksubset_w <- gwindow(title = "Check subsetting",
@@ -263,23 +264,25 @@ calculateBalance_gui <- function(env=parent.frame(), savegui=NULL,
                spacing = 10,
                container = gv) 
 
-  f1_ignore_chk <- gcheckbox(text="Ignore case",
-                         checked=TRUE,
+  f1_ignore_chk <- gcheckbox(text="Ignore case", checked=TRUE,
                          container=f1)
   
-  f1_word_chk <- gcheckbox(text="Add word boundaries",
-                           checked = FALSE,
+  f1_word_chk <- gcheckbox(text="Add word boundaries", checked = FALSE,
                            container = f1)
   
-  f1_drop_chk <- gcheckbox(text="Drop sex markers",
-                           checked=TRUE,
+  f1_drop_chk <- gcheckbox(text="Drop sex markers", checked=TRUE,
                            container=f1)
   
+  f1_h_chk <- gcheckbox(text="Calculate average peak height", checked = TRUE,
+                        container = f1)
+
   f1g1 <- ggroup(horizontal = TRUE, spacing = 5, container = f1)
   glabel(text="Calculate balance using:", anchor=c(-1 ,0), container=f1g1)
-  f1_methods <- c("High molecular weight / low molecular weight", "Smaller peak / larger peak")
+  f1_methods <- c("High molecular weight / low molecular weight",
+                  "Low molecular weight / high molecular weight",
+                  "Smaller peak / larger peak")
   f1_method_drp <- gdroplist(items=f1_methods,
-                             selected = 2,
+                             selected = 1,
                              expand = FALSE,
                              container = f1g1)
   
@@ -295,7 +298,7 @@ calculateBalance_gui <- function(env=parent.frame(), savegui=NULL,
                 "Calculate locus balance globally across all dyes")
   
   f1_perDye_opt <- gradio(items=f1_options_perDye,
-                          selected=1,
+                          selected=2,
                           horizontal=FALSE,
                           container=f1)
 
@@ -338,6 +341,7 @@ calculateBalance_gui <- function(env=parent.frame(), savegui=NULL,
     val_perDye <- svalue(f1_perDye_opt, index=TRUE) == 1 # TRUE / FALSE
     val_ignore <- svalue(f1_ignore_chk)
     val_word <- svalue(f1_word_chk)
+    val_h <- svalue(f1_h_chk)
     val_data <- .gData
     val_ref <- .gRef
     val_name <- svalue(f4_save_edt)
@@ -372,8 +376,10 @@ calculateBalance_gui <- function(env=parent.frame(), savegui=NULL,
         
         if(val_lb == 1){
           val_lb <- "prop"
-        } else {
+        } else if(val_lb == 2) {
           val_lb <- "norm"
+        } else {
+          stop("val_lb =", val_lb, "not implemented!")
         }
   
         if(debug){
@@ -430,8 +436,65 @@ calculateBalance_gui <- function(env=parent.frame(), savegui=NULL,
                                     word=val_word,
                                     debug=debug)
         
-        # Add attribute for detected kit.
+        # Add attributes.
         attr(datanew, which="kit") <- val_kit
+        attr(datanew, which="calculateBalance_gui, data") <- svalue(g0_data_drp)
+        attr(datanew, which="calculateBalance_gui, ref") <- svalue(g0_ref_drp)
+        attr(datanew, which="calculateBalance_gui, lb") <- val_lb
+        attr(datanew, which="calculateBalance_gui, hb") <- val_method
+        attr(datanew, which="calculateBalance_gui, ignore.case") <- val_ignore
+        attr(datanew, which="calculateBalance_gui, word") <- val_word
+        attr(datanew, which="calculateBalance_gui, calculate.h") <- val_h
+        attr(datanew, which="calculateBalance_gui, drop.sex") <- val_drop
+        
+        # Calculate and add average peak height.
+        if(val_h){
+          
+          # Heterozygote status is required to calculate 'H'.        
+          if(!"Heterozygous" %in% names(val_data)){
+            
+            if(!"Heterozygous" %in% names(val_ref)){
+              
+              # Calculate heterozygote indicator for reference set.
+              val_ref <- calculateHeterozygous(data=val_ref, debug=debug)
+              
+              message("Heterozygote indicator calculated for reference set.")
+              
+            }
+            
+            # Filter known profile.
+            val_data <- filterProfile(data=val_data, ref=val_ref,
+                                      add.missing.loci=TRUE, keep.na=TRUE,
+                                      ignore.case=val_ignore,
+                                      invert=FALSE, debug=debug)
+            
+            message("Filter known profile from dataset.")
+            
+            # Add heterozygote indicator to dataset.
+            val_data <- addData(data=val_data, new.data=val_ref,
+                                by.col="Sample.Name", then.by.col="Marker",
+                                exact=FALSE, ignore.case=val_ignore,
+                                debug=debug)
+            
+            message("Heterozygote indicator added to dataset.")
+            
+          }
+          
+          # Calculate average peak height.
+          dfH <- calculateHeight(data=val_data, na=0, add=FALSE,
+                                 exclude="OL", debug=debug)
+          
+          message("Average peak height calculated.")
+          
+          # Add average peak height to dataset.
+          datanew <- addData(data=datanew, new.data=dfH,
+                             by.col="Sample.Name", then.by.col=NULL,
+                             exact=TRUE, ignore.case=val_ignore,
+                             debug=debug)
+          
+          message("Average peak height added to result.")
+          
+        }
         
         # Save data.
         saveObject(name=val_name, object=datanew, parent=w, env=env)
@@ -505,9 +568,15 @@ calculateBalance_gui <- function(env=parent.frame(), savegui=NULL,
       if(exists(".strvalidator_calculateBalance_gui_ignore", envir=env, inherits = FALSE)){
         svalue(f1_ignore_chk) <- get(".strvalidator_calculateBalance_gui_ignore", envir=env)
       }
+      if(exists(".strvalidator_calculateBalance_gui_word", envir=env, inherits = FALSE)){
+        svalue(f1_word_chk) <- get(".strvalidator_calculateBalance_gui_word", envir=env)
+      }
       if(exists(".strvalidator_calculateBalance_gui_sex", envir=env, inherits = FALSE)){
         svalue(f1_drop_chk) <- get(".strvalidator_calculateBalance_gui_sex", envir=env)
       }
+      if(exists(".strvalidator_calculateBalance_gui_h", envir=env, inherits = FALSE)){
+        svalue(f1_h_chk) <- get(".strvalidator_calculateBalance_gui_h", envir=env)
+      }
       if(debug){
         print("Saved settings loaded!")
       }
@@ -525,7 +594,9 @@ calculateBalance_gui <- function(env=parent.frame(), savegui=NULL,
       assign(x=".strvalidator_calculateBalance_gui_lb", value=svalue(f1_lb_opt), envir=env)
       assign(x=".strvalidator_calculateBalance_gui_perDye", value=svalue(f1_perDye_opt), envir=env)
       assign(x=".strvalidator_calculateBalance_gui_ignore", value=svalue(f1_ignore_chk), envir=env)
+      assign(x=".strvalidator_calculateBalance_gui_word", value=svalue(f1_word_chk), envir=env)
       assign(x=".strvalidator_calculateBalance_gui_sex", value=svalue(f1_drop_chk), envir=env)
+      assign(x=".strvalidator_calculateBalance_gui_h", value=svalue(f1_h_chk), envir=env)
       
     } else { # or remove all saved values if false.
       
@@ -544,9 +615,15 @@ calculateBalance_gui <- function(env=parent.frame(), savegui=NULL,
       if(exists(".strvalidator_calculateBalance_gui_ignore", envir=env, inherits = FALSE)){
         remove(".strvalidator_calculateBalance_gui_ignore", envir = env)
       }
+      if(exists(".strvalidator_calculateBalance_gui_word", envir=env, inherits = FALSE)){
+        remove(".strvalidator_calculateBalance_gui_word", envir = env)
+      }
       if(exists(".strvalidator_calculateBalance_gui_sex", envir=env, inherits = FALSE)){
         remove(".strvalidator_calculateBalance_gui_sex", envir = env)
       }
+      if(exists(".strvalidator_calculateBalance_gui_h", envir=env, inherits = FALSE)){
+        remove(".strvalidator_calculateBalance_gui_h", envir = env)
+      }
       
       if(debug){
         print("Settings cleared!")
