@@ -134,7 +134,7 @@ calculateConcordance_gui <- function(env=parent.frame(), savegui=NULL,
                                       " samples)", sep="")
       
       # Detect kit.
-      kitIndex <- detectKit(.gData)
+      kitIndex <- detectKit(.gData, index=TRUE)
       # Select in dropdown.
       svalue(kit_drp, index=TRUE) <- kitIndex
       
