@@ -136,7 +136,7 @@ calculatePullup_gui <- function(env=parent.frame(), savegui=NULL,
       svalue(f4_save_edt) <- paste(val_obj, "_pullup", sep="")
       
       # Detect kit.
-      kitIndex <- detectKit(.gData)
+      kitIndex <- detectKit(.gData, index=TRUE)
       # Select in dropdown.
       svalue(f4_kit_drp, index=TRUE) <- kitIndex
       
