@@ -1,12 +1,13 @@
 ################################################################################
 # TODO LIST
-# TODO: Option to show only 'head' for large datasets. >X rows show head?
-# TODO: Option to show data automatically when selected or just show info
-#  and a button to show data?
+# TODO: View attributes: Does not work well...
 
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 06.01.2016: Fixed attributes window bug. Error when close using X.
+# 26.10.2015: Fixed attributes window bug.
+# 04.10.2015: Added options to limit number of rows, and show attributes.
 # 28.08.2015: Added importFrom.
 # 01.06.2015: Fixed bug column names not saved. Introduced 02.01.2015 with attributes.
 # 11.05.2015: Accepts (the first) column name containing the string 'Sample'
@@ -34,6 +35,7 @@
 #' @details Select a data frame from the dropdown and view/edit. Optionally
 #' save as a new dataframe.
 #' @param env environment in wich to search for data frames.
+#' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param data data.frame for instant viewing.
 #' @param name character string with the name of the provided dataset.
 #' @param edit logical TRUE for enable edit .
@@ -48,9 +50,9 @@
 #' 
 #' @seealso \code{\link{trim_gui}}, \code{\link{cropData_gui}}, \code{\link{combine_gui}}
 
-editData_gui <- function(env=parent.frame(), data=NULL, name=NULL, edit=TRUE,
-                         debug=FALSE, parent=NULL){
-
+editData_gui <- function(env=parent.frame(), savegui=NULL, data=NULL,
+                         name=NULL, edit=TRUE, debug=FALSE, parent=NULL){
+  
   .gData <- data
   .gDataName <- name
   
@@ -64,13 +66,16 @@ editData_gui <- function(env=parent.frame(), data=NULL, name=NULL, edit=TRUE,
     guiTitle="View data frame"
   }
   
+  # Create windows.
   w <- gwindow(title=guiTitle, visible=FALSE)
-  
+  w_attributes <- gwindow(title="Attributes", visible=FALSE)
+  attr_text <- gtext("", container=w_attributes)
+
   # Runs when window is closed.
   addHandlerDestroy(w, handler = function (h, ...) {
     
     # Save GUI state.
-    #.saveSettings()
+    .saveSettings()
     
     # Focus on parent window.
     if(!is.null(parent)){
@@ -84,12 +89,11 @@ editData_gui <- function(env=parent.frame(), data=NULL, name=NULL, edit=TRUE,
                use.scrollwindow=FALSE,
                container = w,
                expand=TRUE) 
-
+  
   # Help button group.
   gh <- ggroup(container = gv, expand=FALSE, fill="both")
   
-  # NO options yet.
-  #savegui_chk <- gcheckbox(text="Save GUI settings", checked=FALSE, container=gh)
+  savegui_chk <- gcheckbox(text="Save GUI settings", checked=FALSE, container=gh)
   
   addSpring(gh)
   
@@ -158,7 +162,8 @@ editData_gui <- function(env=parent.frame(), data=NULL, name=NULL, edit=TRUE,
       svalue(g0_columns_lbl) <- paste(" ", ncol(.gData), "columns,")
       svalue(g0_rows_lbl) <- paste(" ", nrow(.gData), "rows")
       
-      .refresh_tbl()
+      # Refresh info and load table.
+      .refreshTbl()
       
     } else {
       svalue(g0_samples_lbl) <- paste(" ", "<NA>", "samples,")
@@ -169,30 +174,65 @@ editData_gui <- function(env=parent.frame(), data=NULL, name=NULL, edit=TRUE,
   } )  
   
   # FRAME 1 ###################################################################
-
-  f1 <- gframe(text = "Save | Copy",
+  
+  f1 <- gframe(text = "Options",
                horizontal=FALSE,
                spacing = 5,
                container = gv) 
   
   g1 <- glayout(container = f1, spacing = 1)
-    
-  g1[1,1] <- save_btn <- gbutton(text="Save as",
-                              border=TRUE,
-                              container = g1) 
   
-  g1[1,2] <- save_txt <- gedit(text=.gDataName,
-                            container=g1,
-                            anchor=c(-1 ,0))
+  g1[1,1] <- f1_show_attr_chk <- gcheckbox(text="Show attributes (separate window)",
+                                           checked=FALSE, container=g1)
+  
+  
+  g1[2,1] <- f1_limit_chk <- gcheckbox(text="Limit number of rows to:",
+                                       checked=TRUE, container=g1)
+  
+  
+  g1[2,2] <- f1_max_edt <- gedit(text=100, width=8, container=g1)
+  
+  addHandlerChanged(f1_show_attr_chk, handler = function(h, ...) {
 
-  g1[2,1] <- copy_btn <- gbutton(text="Copy to clipboard",
-                                 border=TRUE,
-                                 container = g1) 
+    if(svalue(f1_show_attr_chk)){
+      .showAttributes()
+    } else {
+      if(isExtant(w_attributes)){
+        visible(w_attributes) <- FALSE
+      }
+    }
+    
+  } )
 
-  g1[2,2] <- glabel(text="NB! Dataset might get truncated if too large. Use 'File/Export' instead. ",
-                                 border=TRUE,
-                                 container = g1) 
+  addHandlerChanged(f1_limit_chk, handler = function(h, ...) {
+    
+    .refreshTbl()
 
+  } )
+  
+  
+  # FRAME 2 ###################################################################
+  
+  f2 <- gframe(text = "Copy | Export | Save",
+               horizontal=FALSE,
+               spacing = 5,
+               container = gv) 
+  
+  g2 <- glayout(container = f2, spacing = 1)
+  
+  g2[1,1] <- copy_btn <- gbutton(text="Copy", border=TRUE, container=g2)
+  tooltip(copy_btn) <- "Copy to clipboard (NB! large datasets might get truncated)"
+  
+  g2[1,2] <- export_btn <- gbutton(text="Export", border=TRUE, container=g2)
+  tooltip(export_btn) <- "Opens the export dialog"
+  
+  g2[1,3] <- save_btn <- gbutton(text="Save as", border=TRUE, container=g2)
+  tooltip(save_btn) <- "Save as new dataset"
+  
+  g2[1,4] <- save_txt <- gedit(text=.gDataName,
+                               container=g2, width = 50,
+                               anchor=c(-1 ,0))
+  
   addHandlerChanged(copy_btn, handler = function(h, ...) {
     
     val_tbl <- data_tbl[]
@@ -206,11 +246,11 @@ editData_gui <- function(env=parent.frame(), data=NULL, name=NULL, edit=TRUE,
                 sep="\t", row.names=FALSE)
     
     # Change button.
-    svalue(copy_btn) <- "Copy to clipboard"
+    svalue(copy_btn) <- "Copy"
     enabled(copy_btn) <- TRUE
-
+    
   } )
-
+  
   addHandlerChanged(save_btn, handler = function(h, ...) {
     
     val_name <- svalue(save_txt)
@@ -222,7 +262,7 @@ editData_gui <- function(env=parent.frame(), data=NULL, name=NULL, edit=TRUE,
     }
     
     if (!is.na(val_name) && !is.null(val_name)){
-
+      
       # Copy and add attributes (retain names).
       names(.gData) <- names(datanew)
       attributes(datanew) <- attributes(.gData)
@@ -230,14 +270,14 @@ editData_gui <- function(env=parent.frame(), data=NULL, name=NULL, edit=TRUE,
       # Change button.
       svalue(save_btn) <- "Saving..."
       enabled(save_btn) <- FALSE
-
+      
       # Save data.
       saveObject(name=val_name, object=datanew, parent=w, env=env, debug=debug)
       
       # Change button.
       svalue(save_btn) <- "Save as"
       enabled(save_btn) <- TRUE
-    
+      
     } else {
       
       gmessage(message="A name must be given!",
@@ -248,19 +288,31 @@ editData_gui <- function(env=parent.frame(), data=NULL, name=NULL, edit=TRUE,
     
   } )
   
-  # FRAME 2 ###################################################################
+  addHandlerChanged(export_btn, handler = function(h, ...) {
+    
+    # Open GUI.
+    export_gui(env=env, savegui=savegui, debug=debug, parent=parent)
+    
+  } )
   
-  f2 <- gframe(text = "Data frame",
+  # FRAME 3 ###################################################################
+  
+  f3 <- gframe(text = "Data frame",
                horizontal=FALSE,
                spacing = 5,
                expand=TRUE,
                container = gv) 
-
+  
   if(is.null(.gData)){
-      data_tbl <- gWidgets::gtable(items=data.frame(Data="There is no data"),
-                         container=f2, expand=TRUE)
+    data_tbl <- gWidgets::gtable(items=data.frame(Data="There is no data"),
+                                 container=f3, expand=TRUE)
   } else {
     
+    # Get options.
+    val_limit <- svalue(f1_limit_chk)
+    val_max <- as.numeric(svalue(f1_max_edt))
+    val_attr <- svalue(f1_show_attr_chk) 
+    
     # Update info.
     if("Sample.Name" %in% names(.gData)){
       samples <- length(unique(.gData$Sample.Name))
@@ -277,41 +329,206 @@ editData_gui <- function(env=parent.frame(), data=NULL, name=NULL, edit=TRUE,
     svalue(g0_samples_lbl) <- paste(" ", samples, "samples,")
     svalue(g0_columns_lbl) <- paste(" ", ncol(.gData), "columns,")
     svalue(g0_rows_lbl) <- paste(" ", nrow(.gData), "rows")
-
+    
     # Load data.
     if(edit){
-      data_tbl <- gdf(items=.gData, container=f2, expand=TRUE)
+      if(val_limit){
+        data_tbl <<- gdf(items=head(.gData, val_max),
+                         container=f3, expand=TRUE)
+      } else {
+        data_tbl <<- gdf(items=.gData, container=f3, expand=TRUE)
+      }
     } else {
-      data_tbl <- gWidgets::gtable(items=.gData, container=f2, expand=TRUE)
+      if(val_limit){
+        data_tbl <<- gWidgets::gtable(items=head(.gData, val_max),
+                                      container=f3, expand=TRUE)
+      } else {
+        data_tbl <<- gWidgets::gtable(items=.gData, container=f3, expand=TRUE)
+      }
     }
+    
   }
   
-  # FUNCTIONS #################################################################
-
-  .refresh_tbl <- function(){
+  # INTERNAL FUNCTIONS ########################################################
+  
+  .showAttributes <- function(){
     
     if(debug){
       print(paste("IN:", match.call()[[1]]))
     }
     
-    # Update "save as" with current dataset name.
-    svalue(save_txt) <- paste(.gDataName, "_edit", sep="")
+    # Get options.
+    val_attr <- svalue(f1_show_attr_chk)
     
-    # Refresh widget by removing it and...
-    delete(f2, data_tbl)
-    
-    visible(f2) <- FALSE
-    # ...creating a new table.
-    if(edit){
-      data_tbl <<- gdf(items=.gData, container=f2, expand=TRUE)
-    } else {
-      data_tbl <<- gWidgets::gtable(items=.gData, container=f2, expand=TRUE)
+    if(val_attr & !is.null(.gData)){
+      
+      if(!isExtant(w_attributes)){
+
+        # Re-create window.        
+        w_attributes <<- gwindow(title="Attributes", visible=FALSE)
+        attr_text <<- gtext("", container=w_attributes)
+
+      }
+
+      # Get list of attributes.
+      attributeList <- attributes(.gData)
+      
+      # Remove common non-strvalidator attributes (too much to show).
+      attributeList$names <- NULL
+      attributeList$row.names <- NULL
+      attributeList$class <- NULL
+      
+      # Empty text fiels.
+      svalue(attr_text) <- ""
+
+      # Get names of attributes.      
+      attrNames <- names(attributeList)
+
+      # Loop over list of attributes and att to text object.
+      for(a in seq(along=attrNames)){
+        
+        # Insert text for current attribute.        
+        insert(attr_text, paste(attrNames[a], attributeList[a], sep=": "))
+        
+      }
+
+      # Show window.
+      visible(w_attributes) <- TRUE  
+      
     }
     
-    visible(f2) <- TRUE
-    
   }
   
+  .refreshTbl <- function(){
+    
+    if(debug){
+      print(paste("IN:", match.call()[[1]]))
+    }
+    
+    # Get options.
+    val_limit <- svalue(f1_limit_chk)
+    val_max <- as.numeric(svalue(f1_max_edt))
+    val_attr <- svalue(f1_show_attr_chk) 
+    
+    if(!is.null(.gData)){
+
+      if(val_attr){
+        .showAttributes()
+      }
+      
+      # Update "save as" with current dataset name.
+      svalue(save_txt) <- paste(.gDataName, "_edit", sep="")
+      
+      # Refresh widget by removing it and...
+      delete(f3, data_tbl)
+      
+      visible(f3) <- FALSE
+      # ...creating a new table.
+      if(edit){
+        if(val_limit){
+          data_tbl <<- gdf(items=head(.gData, val_max),
+                           container=f3, expand=TRUE)
+        } else {
+          data_tbl <<- gdf(items=.gData, container=f3, expand=TRUE)
+        }
+      } else {
+        if(val_limit){
+          data_tbl <<- gWidgets::gtable(items=head(.gData, val_max),
+                                        container=f3, expand=TRUE)
+        } else {
+          data_tbl <<- gWidgets::gtable(items=.gData, container=f3, expand=TRUE)
+        }
+      }
+      
+      visible(f3) <- TRUE
+      
+    }
+    
+  }
+  
+  .loadSavedSettings <- function(){
+    
+    # First check status of save flag.
+    if(!is.null(savegui)){
+      svalue(savegui_chk) <- savegui
+      enabled(savegui_chk) <- FALSE
+      if(debug){
+        print("Save GUI status set!")
+      }  
+    } else {
+      # Load save flag.
+      if(exists(".strvalidator_editData_gui_savegui", envir=env, inherits = FALSE)){
+        svalue(savegui_chk) <- get(".strvalidator_editData_gui_savegui", envir=env)
+      }
+      if(debug){
+        print("Save GUI status loaded!")
+      }
+    }
+        
+    if(debug){
+      print(svalue(savegui_chk))
+    }
+
+    # Then load settings if true.
+    if(svalue(savegui_chk)){
+      if(exists(".strvalidator_editData_gui_attr", envir=env, inherits = FALSE)){
+        svalue(f1_show_attr_chk) <- get(".strvalidator_editData_gui_attr", envir=env)
+      }
+      if(exists(".strvalidator_editData_gui_limit", envir=env, inherits = FALSE)){
+        svalue(f1_limit_chk) <- get(".strvalidator_editData_gui_limit", envir=env)
+      }
+      if(exists(".strvalidator_editData_gui_maxrow", envir=env, inherits = FALSE)){
+        svalue(f1_max_edt) <- get(".strvalidator_editData_gui_maxrow", envir=env)
+      }
+      
+      if(debug){
+        print("Saved settings loaded!")
+      }
+    }
+    
+  }
+  
+  .saveSettings <- function(){
+      
+    # Then save settings if true.
+    if(svalue(savegui_chk)){
+      
+      assign(x=".strvalidator_editData_gui_savegui", value=svalue(savegui_chk), envir=env)
+      assign(x=".strvalidator_editData_gui_attr", value=svalue(f1_show_attr_chk), envir=env)
+      assign(x=".strvalidator_editData_gui_limit", value=svalue(f1_limit_chk), envir=env)
+      assign(x=".strvalidator_editData_gui_maxrow", value=svalue(f1_max_edt), envir=env)
+      
+    } else { # or remove all saved values if false.
+      
+      if(exists(".strvalidator_editData_gui_savegui", envir=env, inherits = FALSE)){
+        remove(".strvalidator_editData_gui_savegui", envir = env)
+      }
+      if(exists(".strvalidator_editData_gui_attr", envir=env, inherits = FALSE)){
+        remove(".strvalidator_editData_gui_attr", envir = env)
+      }
+      if(exists(".strvalidator_editData_gui_limit", envir=env, inherits = FALSE)){
+        remove(".strvalidator_editData_gui_limit", envir = env)
+      }
+      if(exists(".strvalidator_editData_gui_maxrow", envir=env, inherits = FALSE)){
+        remove(".strvalidator_editData_gui_maxrow", envir = env)
+      }
+      
+      if(debug){
+        print("Settings cleared!")
+      }
+    }
+    
+    if(debug){
+      print("Settings saved!")
+    }
+    
+  }
+  
+  # END GUI ###################################################################
+  
+  # Load GUI settings.
+  .loadSavedSettings()
+    
   # Show GUI.
   visible(w) <- TRUE
   focus(w)
