@@ -1,9 +1,13 @@
 ################################################################################
 # TODO LIST
-# TODO: Fix TODO's in code (nb observations etc.)
+# TODO: ...
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 06.01.2016: Fixed theme methods not found and added more themes.
+# 11.11.2015: Added importFrom ggplot2.
+# 11.11.2015: Added more themes.
+# 07.10.2015: NA's now removed prior to plotting, and from number of observations.
 # 29.08.2015: Added importFrom.
 # 11.06.2015: Fixed title for histogram plot.
 # 09.06.2015: Fixed 'overlay boxplot' not saved.
@@ -40,6 +44,10 @@
 #' @export
 #' 
 #' @importFrom utils help str head
+#' @importFrom ggplot2 qplot ggplot aes_string stat_ecdf geom_density ggplot_build
+#'  geom_boxplot geom_segment geom_point labs theme_gray theme_bw
+#'  theme_linedraw theme_light theme_dark theme_minimal theme_classic
+#'  theme_void 
 #' 
 #' @return TRUE
 
@@ -232,8 +240,11 @@ plotDistribution_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
   
   f1g2 <- glayout(container = f1, spacing = 1)
   f1g2[1,1] <- glabel(text="Plot theme:", anchor=c(-1 ,0), container=f1g2)
-  f1g2[1,2] <- f1_theme_drp <- gdroplist(items=c("theme_grey()","theme_bw()"),
-                                         selected=1,
+  items_theme <- c("theme_grey()","theme_bw()","theme_linedraw()",
+                   "theme_light()","theme_dark()","theme_minimal()",
+                   "theme_classic()","theme_void()")
+  f1g2[1,2] <- f1_theme_drp <- gdroplist(items = items_theme,
+                                         selected = 1,
                                          container = f1g2)
   
   f1e1 <- gexpandgroup(text = "Boxplot", horizontal=FALSE,
@@ -471,28 +482,26 @@ plotDistribution_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
         print(head(val_data))
       }
       
-      # TODO: Remove NA
-      #       # Remove NA's
-      #       if(any(is.na(val_data[, val_column]))){
-      #         
-      #         # Store nb of observations.
-      #         nb0 <- nb
-      #         
-      #         # Update number of observations.
-      #         nb <- nrow(val_data[!is.na(val_data[val_column]),])
-      #         
-      #         # Show message.
-      #         message(paste("Removed ", nb0-nb, " NA rows.", sep=""))
-      #         
-      #         if(debug){
-      #           print("After subsetting (val_data)")
-      #           print(str(val_data))
-      #           print(head(val_data))
-      #         }
-      #         
-      #       }
-      
-      
+      # Remove NA's
+      if(any(is.na(val_data[, val_column]))){
+        
+        # Store nb of observations.
+        nb0 <- nb
+        
+        # Update number of observations.
+        nb <- nrow(val_data[!is.na(val_data[val_column]),])
+        
+        # Show message.
+        message(paste("Removed ", nb0-nb, " NA rows.", sep=""))
+        
+        if(debug){
+          print("After subsetting (val_data)")
+          print(str(val_data))
+          print(head(val_data))
+        }
+        
+      }
+
       # Create titles.
       if(val_titles){
         
