@@ -15,10 +15,22 @@
 # IMPORTANT: Use build_win() to test on current R and R-dev 'library(devtools)'.
 # IMPORTANT: Use devtools::release() to submitt to CRAN.
 
-# Versioning convention (x.yy.z):
+# Versioning convention (x.yy.z[.9###]):
 # Increment x on major change.
 # Increment yy on new features.
 # Increment z on minor changes and bug fixes.
+# [optional]Increment ### on development versions.
+# NB! Write changes in NEWS for x.yy.z.9### versions, but move changes to NEWS under x.yy.z upon release official version.
+
+# Attributes:
+# Put these in 'base functions':
+# attr(dataDrop, which="[function], strvalidator") <- as.character(utils::packageVersion("strvalidator"))
+# attr(dataDrop, which="[function], call") <- match.call()
+# attr(at.rank, which="[function], date") <- date()
+# Add additional attributes as:
+# attr(datanew, which="[function], [attribute]") <- parameter
+# Except for 'global' parameters used by other functions:
+# attr(datanew, which="kit") <- kit
 
 # NOTE:
 # NOTE: Can't import data frame named 'drop'
@@ -27,6 +39,12 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 30.12.2015: Added button to new function 'calculateLb' in the 'Balance' tab.
+# 22.12.2015: Added new group 'Marker ratio' in the 'Balance' tab.
+# 18.12.2015: Added tooltips in the 'Workspace' tab.
+# 30.11.2015: Moved updated description. Previous information moved to 'strvalidator-package'.
+# 12.10.2015: Added 'Calculate' and 'Filter' button in 'Result' tab.
+# 12.10.2015: Added new group 'Drop-in tools' in 'Result' tab.
 # 29.08.2015: Added importFrom.
 # 01.06.2015: Added 'Calculate' and 'Plot' (AT6) button in 'AT' tab.
 # 24.05.2015: Added 'Columns' button in 'Tools' tab.
@@ -41,61 +59,30 @@
 # 08.07.2014: Added 'Mixture' tab.
 # 04.07.2014: Ask to overwrite project file if exist.
 # 04.07.2014: Added new button 'Add' and 'Save As' to 'Workspace' tab.
-# 30.06.2014: Added 'Projects' tab.
-# 28.06.2014: Added help button and moved save gui checkbox.
-# 23.06.2014: Added options("guiToolkit"="RGtk2") bugs when using TclTK.
-# 22.06.2014: Added 'Concordance' tab.
-# 17.06.2014: Added version number in title.
-# 15.02.2014: Added 'Summarize' balance data button in 'Balance' tab.
-# 11.02.2014: Added 'Add Size' button in edit tab.
 
 #' @title Graphical User Interface For The STR-validator Package
 #'
 #' @description
-#' Validation and process control toolbox for forensic genetic laboratories.
+#' GUI simplifying the use of the STR-validator package.
 #'
-#' @details STR-validator (pronounced starvalidator) is a package developed
-#' for validation and process control of both methods and instruments in a
-#' forensic genetic laboratory setting.
-#' This graphical user interface make it very easy to analyse validation
-#' data in accordance with ENFSI and SWGDAM guidelines.
-#' The code has been extensively tested in order to assure correct results.\cr\cr
-#' 
-#' Open the help page and click \code{Index} at the bottom of the page
-#' to see a list of all functions.\cr\cr
-#' 
-#' Created by:\cr
-#' Oskar Hansson, Department of Forensic Biology (NIPH, Norway)\cr\cr
-#' 
-#' General user information and tutorials:\cr
-#' \url{https://sites.google.com/site/forensicapps/strvalidator}\cr\cr
-#' 
-#' Facebook user community:\cr
-#' \url{https://www.facebook.com/pages/STR-validator/240891279451450?ref=tn_tnmn}\cr\cr
-#' \url{https://www.facebook.com/groups/strvalidator/}\cr\cr
-#' 
-#' Please report bugs to:\cr
-#' \url{https://github.com/OskarHansson/strvalidator/issues}\cr\cr
-#' 
-#' The source code and collaborative community is hosted at GitHub:\cr
-#' \url{https://github.com/OskarHansson/strvalidator}\cr\cr
+#' @details The graphical user interface give easy access to all graphical
+#' versions of the functions available in the strvalidator package. It connects
+#' functions 'under the hood' to allow a degree of automation not available
+#' using the command based functions. In addition it provides a project based
+#' workflow.\cr\cr
+#' Click \code{Index} at the bottom of the help page to see a complete list
+#' of functions.
 #' 
 #' @param debug logical indicating printing debug information.
 #' 
 #' @return TRUE
 #' 
-#' @references
-#' Recommended Minimum Criteria for the Validation of Various Aspects of the DNA Profiling Process
-#' (access have been unstable lately but it is usually found at http://www.enfsi.eu/sites/default/files/documents/minimum_validation_guidelines_in_dna_profiling_-_v2010_0.pdf)
-#' Validation Guidelines for Forensic DNA Analysis Methods (2012)
-#' \url{http://swgdam.org/SWGDAM_Validation_Guidelines_APPROVED_Dec_2012.pdf}
-#' 
-#' @import ggplot2
+# @import ggplot2
 #' @import gWidgets
 #' @import gWidgetsRGtk2
 #' @import RGtk2
-#' @import data.table
-#' @import gridExtra
+# @import data.table
+# @import gridExtra
 #' @importFrom utils packageVersion help object.size
 #' @importFrom graphics title
 #' 
@@ -390,17 +377,15 @@ strvalidator <- function(debug=FALSE){
   
   glabel("", container=project_g1) # Adds some space.
   
-  project_open_btn <- gbutton(text="Open",
-                              border=TRUE,
-                              container = project_g1)
+  project_open_btn <- gbutton(text="Open", border=TRUE, container = project_g1)
+  tooltip(project_open_btn) <- "Open selected project"
+
+  project_add_btn <- gbutton(text="Add", border=TRUE, container = project_g1)
+  tooltip(project_add_btn) <- "Merge with current project"
   
-  project_add_btn <- gbutton(text="Add",
-                             border=TRUE,
-                             container = project_g1)
-  
-  project_delete_btn <- gbutton(text="Delete",
-                                border=TRUE,
+  project_delete_btn <- gbutton(text="Delete", border=TRUE,
                                 container = project_g1)
+  tooltip(project_delete_btn) <- "Delete selected project from the file system"
   
   addSpring(project_g1)
   
@@ -571,14 +556,12 @@ strvalidator <- function(debug=FALSE){
                        expand=TRUE)
   
   # Button group.
-  project_g3 <- ggroup(horizontal=FALSE,
-                       spacing=10,
-                       container = project_f3,
-                       expand=FALSE)
+  project_g3 <- ggroup(horizontal = FALSE, spacing = 10,
+                       container = project_f3, expand = FALSE)
+  
+  project_save_btn <- gbutton(text="Save", border=TRUE, container = project_g3)
+  tooltip(project_save_btn) <- "Save project description"
   
-  project_save_btn <- gbutton(text="Save",
-                              border=TRUE,
-                              container = project_g3)
   
   glabel("", container=project_g1) # Adds some space.
   
@@ -638,42 +621,52 @@ strvalidator <- function(debug=FALSE){
   ws_open_btn <- gbutton(text="Open",
                          border=TRUE,
                          container = workspace_f1g1)
+  tooltip(ws_open_btn) <- "Open project"
   
   ws_save_btn <- gbutton(text="Save",
                          border=TRUE,
                          container = workspace_f1g1)
+  tooltip(ws_save_btn) <- "Save project"
   
   ws_saveas_btn <- gbutton(text="Save As",
                            border=TRUE,
                            container = workspace_f1g1)
+  tooltip(ws_saveas_btn) <- "Choose a location and save project"
   
   ws_import_btn <- gbutton(text="Import",
                            border=TRUE,
                            container = workspace_f1g1)
+  tooltip(ws_import_btn) <- "Import data from file"
   
   ws_export_btn <- gbutton(text="Export",
                            border=TRUE,
                            container = workspace_f1g1)
+  tooltip(ws_export_btn) <- "Open the export dialoge"
   
   ws_add_btn <- gbutton(text="Add",
                         border=TRUE,
                         container = workspace_f1g1)
+  tooltip(ws_add_btn) <- "Merge a project with the current project"
   
   ws_refresh_btn <- gbutton(text="Refresh",
                             border=TRUE,
                             container = workspace_f1g1) 
+  tooltip(ws_refresh_btn) <- "Refresh the workspace"
   
   ws_remove_btn <- gbutton(text="Delete",
                            border=TRUE,
                            container = workspace_f1g1) 
+  tooltip(ws_remove_btn) <- "Delete selected object"
   
   ws_rename_btn <- gbutton(text="Rename",
                            border=TRUE,
                            container = workspace_f1g1)
+  tooltip(ws_rename_btn) <- "Rename selected object"
   
   ws_view_btn <- gbutton(text="View",
                          border=TRUE,
                          container = workspace_f1g1)
+  tooltip(ws_view_btn) <- "View selected object"
   
   ws_loaded_tbl <- gWidgets::gtable(items=data.frame(Object="", Size="",
                                                      stringsAsFactors=FALSE), 
@@ -804,6 +797,7 @@ strvalidator <- function(debug=FALSE){
         
         # Open GUI.
         editData_gui(env=.strvalidator_env,
+                     savegui=.save_gui,
                      data=get(val_obj, envir=.strvalidator_env),
                      name=val_obj,
                      edit=FALSE, debug=debug, parent=w)
@@ -1098,7 +1092,8 @@ strvalidator <- function(debug=FALSE){
   addHandlerChanged(dry_view_btn, handler = function(h, ...) {
     
     # Open GUI.
-    editData_gui(env=.strvalidator_env, edit=TRUE, debug=debug, parent=w)
+    editData_gui(env=.strvalidator_env, savegui=.save_gui,
+                 edit=TRUE, debug=debug, parent=w)
     
   } )
   
@@ -1184,7 +1179,8 @@ strvalidator <- function(debug=FALSE){
   addHandlerChanged(edit_view_btn, handler = function(h, ...) {
     
     # Open GUI.
-    editData_gui(env=.strvalidator_env, edit=TRUE, debug=debug, parent=w)
+    editData_gui(env=.strvalidator_env, savegui=.save_gui,
+                 edit=TRUE, debug=debug, parent=w)
     
   } )
   
@@ -1465,7 +1461,8 @@ strvalidator <- function(debug=FALSE){
   addHandlerChanged(at_view_btn, handler = function(h, ...) {
     
     # Open GUI.
-    editData_gui(env=.strvalidator_env, edit=TRUE, debug=debug, parent=w)
+    editData_gui(env=.strvalidator_env, savegui=.save_gui
+                 , edit=TRUE, debug=debug, parent=w)
     
   } )
   
@@ -1538,7 +1535,8 @@ strvalidator <- function(debug=FALSE){
   addHandlerChanged(stutter_view_btn, handler = function(h, ...) {
     
     # Open GUI.
-    editData_gui(env=.strvalidator_env, edit=TRUE, debug=debug, parent=w)
+    editData_gui(env=.strvalidator_env, savegui=.save_gui,
+                 edit=TRUE, debug=debug, parent=w)
     
   } )
   
@@ -1615,7 +1613,8 @@ strvalidator <- function(debug=FALSE){
   addHandlerChanged(balance_view_btn, handler = function(h, ...) {
     
     # Open GUI.
-    editData_gui(env=.strvalidator_env, edit=TRUE, debug=debug, parent=w)
+    editData_gui(env=.strvalidator_env, savegui=.save_gui,
+                 edit=TRUE, debug=debug, parent=w)
     
   } )
   
@@ -1627,29 +1626,46 @@ strvalidator <- function(debug=FALSE){
   balance_g2 <- glayout(container = balance_f2)
   
   # CALCULATE -----------------------------------------------------------------
-  
-  balance_g2[1,1] <- balance_g3_calc_btn <- gbutton(text="Calculate",
+
+  # FUNCTION 1.  
+  balance_g2[1,1] <- balance_g2_calc_1_btn <- gbutton(text="Calculate",
                                                     border=TRUE,
                                                     container = balance_g2) 
   
-  balance_g2[1,2] <- glabel(text="Calculate intra/inter locus balance for a dataset.",
+  balance_g2[1,2] <- glabel(text="Calculate intra/inter locus balance for a dataset (reference required).",
                             container=balance_g2)
   
   
-  addHandlerChanged(balance_g3_calc_btn, handler = function(h, ...) {
+  addHandlerChanged(balance_g2_calc_1_btn, handler = function(h, ...) {
     
     # Open GUI.
     calculateBalance_gui(env=.strvalidator_env, savegui=.save_gui, debug=debug, parent=w)
     
   } )
   
-  # PLOT ----------------------------------------------------------------------
-  
-  balance_g2[2,1] <- balance_g2_plot_btn <- gbutton(text="Plot",
+  # FUNCTION 2.
+  balance_g2[2,1] <- balance_g2_calc_2_btn <- gbutton(text="Calculate",
                                                     border=TRUE,
                                                     container = balance_g2) 
   
-  balance_g2[2,2] <- glabel(text="Create plots for analysed data",
+  balance_g2[2,2] <- glabel(text="Calculate inter locus balance for a dataset (no reference required).",
+                            container=balance_g2)
+  
+  
+  addHandlerChanged(balance_g2_calc_2_btn, handler = function(h, ...) {
+    
+    # Open GUI.
+    calculateLb_gui(env=.strvalidator_env, savegui=.save_gui, debug=debug, parent=w)
+    
+  } )
+  
+  # PLOT ----------------------------------------------------------------------
+  
+  balance_g2[3,1] <- balance_g2_plot_btn <- gbutton(text="Plot",
+                                                    border=TRUE,
+                                                    container = balance_g2) 
+  
+  balance_g2[3,2] <- glabel(text="Create plots for analysed data",
                             container=balance_g2)
   
   addHandlerChanged(balance_g2_plot_btn, handler = function(h, ...) {
@@ -1661,11 +1677,11 @@ strvalidator <- function(debug=FALSE){
   
   # SUMMARY TABLE -------------------------------------------------------------
   
-  balance_g2[3,1] <- balance_table_btn <- gbutton(text="Summarize",
+  balance_g2[4,1] <- balance_table_btn <- gbutton(text="Summarize",
                                                   border=TRUE,
                                                   container = balance_g2) 
   
-  balance_g2[3,2] <- glabel(text="Summarize balance data in a table.",
+  balance_g2[4,2] <- glabel(text="Summarize balance data in a table.",
                             container=balance_g2)
   
   addHandlerChanged(balance_table_btn, handler = function(h, ...) {
@@ -1731,6 +1747,46 @@ strvalidator <- function(debug=FALSE){
     tableCapillary_gui(env=.strvalidator_env, savegui=.save_gui, debug=debug, parent=w)
     
   } )
+
+  # MARKER RATIO ==============================================================
+  
+  balance_f4 <- gframe(text = "Marker peak height ratio",
+                       horizontal=FALSE, container = balance_tab) 
+  
+  balance_g4 <- glayout(container = balance_f4)
+  
+  # CALCULATE -----------------------------------------------------------------
+  
+  balance_g4[1,1] <- balance_g4_calc_btn <- gbutton(text="Calculate",
+                                                    border=TRUE,
+                                                    container = balance_g4) 
+  
+  balance_g4[1,2] <- glabel(text="Calculate locus ratio for a dataset.",
+                            container=balance_g4)
+  
+  
+  addHandlerChanged(balance_g4_calc_btn, handler = function(h, ...) {
+    
+    # Open GUI.
+    calculateRatio_gui(env=.strvalidator_env, savegui=.save_gui, debug=debug, parent=w)
+    
+  } )
+  
+  # PLOT ----------------------------------------------------------------------
+  
+  balance_g4[2,1] <- balance_g4_plot_btn <- gbutton(text="Plot",
+                                                    border=TRUE,
+                                                    container = balance_g4)
+  
+  balance_g4[2,2] <- glabel(text="Create plots for analysed data",
+                            container=balance_g4)
+  
+  addHandlerChanged(balance_g4_plot_btn, handler = function(h, ...) {
+    
+    # Open GUI.
+    plotRatio_gui(env=.strvalidator_env, savegui=.save_gui, debug=debug, parent=w)
+    
+  } )
   
   # CONCORDANCE  ##############################################################
   
@@ -1751,7 +1807,8 @@ strvalidator <- function(debug=FALSE){
   addHandlerChanged(conc_view_btn, handler = function(h, ...) {
     
     # Open GUI.
-    editData_gui(env=.strvalidator_env, edit=TRUE, debug=debug, parent=w)
+    editData_gui(env=.strvalidator_env, savegui=.save_gui,
+                 edit=TRUE, debug=debug, parent=w)
     
   } )
   
@@ -1792,7 +1849,8 @@ strvalidator <- function(debug=FALSE){
   addHandlerChanged(drop_view_btn, handler = function(h, ...) {
     
     # Open GUI.
-    editData_gui(env=.strvalidator_env, edit=TRUE, debug=debug, parent=w)
+    editData_gui(env=.strvalidator_env, savegui=.save_gui,
+                 edit=TRUE, debug=debug, parent=w)
     
   } )
   
@@ -1868,7 +1926,8 @@ strvalidator <- function(debug=FALSE){
   addHandlerChanged(mix_view_btn, handler = function(h, ...) {
     
     # Open GUI.
-    editData_gui(env=.strvalidator_env, edit=TRUE, debug=debug, parent=w)
+    editData_gui(env=.strvalidator_env, savegui=.save_gui,
+                 edit=TRUE, debug=debug, parent=w)
     
   } )
   
@@ -1913,7 +1972,8 @@ strvalidator <- function(debug=FALSE){
   addHandlerChanged(result_view_btn, handler = function(h, ...) {
     
     # Open GUI.
-    editData_gui(env=.strvalidator_env, edit=TRUE, debug=debug, parent=w)
+    editData_gui(env=.strvalidator_env, savegui=.save_gui,
+                 edit=TRUE, debug=debug, parent=w)
     
   } )
   
@@ -2048,6 +2108,52 @@ strvalidator <- function(debug=FALSE){
     plotDistribution_gui(env=.strvalidator_env, savegui=.save_gui, debug=debug, parent=w)
     
   } )
+
+    
+  # DROPIN ====================================================================
+  
+  result_f5 <- gframe(text = "Drop-in tools",
+                      horizontal=FALSE, container = result_tab) 
+  
+  result_g5 <- glayout(container = result_f5)
+  
+  
+  # CALCULATE -----------------------------------------------------------------
+  
+  result_g5[1,1] <- result_g5_calc_btn <- gbutton(text="Calculate",
+                                                  border=TRUE,
+                                                  container = result_g5) 
+  
+  result_g5[1,2] <- glabel(text="Find spikes in sample.",
+                           container=result_g5,
+                           anchor=c(-1 ,0))
+  
+  
+  addHandlerChanged(result_g5_calc_btn, handler = function(h, ...) {
+    
+    # Open GUI.
+    calculateSpike_gui(env=.strvalidator_env, savegui=.save_gui, debug=debug, parent=w)
+    
+  } )
+  
+  # FILTER PEAKS --------------------------------------------------------------
+  
+  result_g5[2,1] <- result_g5_filter_btn <- gbutton(text="Filter",
+                                                  border=TRUE,
+                                                  container = result_g5) 
+  
+  result_g5[2,2] <- glabel(text="Filter spikes from data.",
+                           container=result_g5)
+  
+  addHandlerChanged(result_g5_filter_btn, handler = function(h, ...) {
+    
+    # Open GUI.
+    #filterSpike_gui(env=.strvalidator_env, savegui=.save_gui, debug=debug, parent=w)
+    gmessage(message = "This function is not yet implemented", title = "No function",
+             icon = "warning", parent = w)
+    
+    
+  } )
   
   # PRECISION  ################################################################
   
@@ -2068,7 +2174,8 @@ strvalidator <- function(debug=FALSE){
   addHandlerChanged(precision_view_btn, handler = function(h, ...) {
     
     # Open GUI.
-    editData_gui(env=.strvalidator_env, edit=TRUE, debug=debug, parent=w)
+    editData_gui(env=.strvalidator_env, savegui=.save_gui,
+                 edit=TRUE, debug=debug, parent=w)
     
   } )
   
@@ -2125,7 +2232,8 @@ strvalidator <- function(debug=FALSE){
   addHandlerChanged(pull_view_btn, handler = function(h, ...) {
     
     # Open GUI.
-    editData_gui(env=.strvalidator_env, edit=TRUE, debug=debug, parent=w)
+    editData_gui(env=.strvalidator_env, savegui=.save_gui,
+                 edit=TRUE, debug=debug, parent=w)
     
   } )
   
@@ -2360,5 +2468,6 @@ strvalidator <- function(debug=FALSE){
   svalue(nb)<-1
   visible(w)<-TRUE
   focus(w)
+  message("STR-validator graphical user interface loaded!")
   
 } # END OF GUI
